# Legislice

[![An Ethical Open Source Project](https://img.shields.io/badge/open-ethical-%234baaaa)](https://ethicalsource.dev/licenses/) [![Tests](https://github.com/mscarey/legislice/actions/workflows/python-package-2.yml/badge.svg)](https://github.com/mscarey/legislice/actions) [![Coverage Status](https://coveralls.io/repos/github/mscarey/legislice/badge.svg?branch=master)](https://coveralls.io/github/mscarey/legislice?branch=master) [![Documentation Status](https://readthedocs.org/projects/legislice/badge/?version=latest)](https://legislice.readthedocs.io/en/latest/?badge=latest)[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/legislice)](https://pypi.org/project/legislice/)


Legislice is a utility for downloading the text of statutes and constitutional provisions, and then creating computable objects representing passages from those provisions. Legislice is used by [AuthoritySpoke](https://authorityspoke.readthedocs.io).

View the [documentation on ReadTheDocs](https://legislice.readthedocs.io/en/latest/).
